@@ -5,9 +5,9 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::ETHER::AUTHORITY = 'cpan:ETHER';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.032';
+  $Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.033';
 }
-# git description: v0.031-8-gc720ab3
+# git description: v0.032-4-g96140dc
 
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 
@@ -96,8 +96,7 @@ sub configure
         [ 'FileFinder::ByName' => Examples => { dir => 'examples' } ],
 
         # Gather Files
-        # FIXME - exclude_filename should be an exact (anchored) match
-        [ 'Git::GatherDir'      => { exclude_match => [ qw(^LICENSE$ ^CONTRIBUTING$) ] } ],
+        [ 'Git::GatherDir'      => { ':version' => '2.016', exclude_filename => [ qw(README.md LICENSE CONTRIBUTING) ] } ],
         qw(MetaYAML MetaJSON License Readme Manifest),
         [ 'GenerateFile::ShareDir' => { -dist => 'Dist-Zilla-PluginBundle-Author-ETHER', -filename => 'CONTRIBUTING' } ],
 
@@ -177,18 +176,17 @@ sub configure
         'RunExtraTests',
 
         # Install Tool
-        [ 'ReadmeAnyFromPod'    => { type => 'markdown', filename => 'README.md', location => 'root' } ],
+        [ 'ReadmeAnyFromPod'    => { type => 'markdown', filename => 'README.md', location => 'build' } ],
         ( map { [ $_ => $installer_args{$_} // () ] } $self->installer ),
         'InstallGuide',
 
         # After Build
         'CheckSelfDependency',
-        [ 'CopyFilesFromBuild'  => { copy => [ qw(LICENSE CONTRIBUTING) ] } ],
         [ 'Run::AfterBuild' => { run => q{if [ `dirname %d` != .build ]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi} } ],
 
 
         # Before Release
-        [ 'Git::Check'          => { allow_dirty => [ qw(README.md LICENSE CONTRIBUTING) ] } ],
+        [ 'Git::Check'          => { allow_dirty => [] } ],
         'Git::CheckFor::MergeConflicts',
         [ 'Git::CheckFor::CorrectBranch' => { ':version' => '0.004', release_branch => 'master' } ],
         [ 'Git::Remote::Check'  => { branch => 'master', remote_branch => 'master' } ],
@@ -200,6 +198,7 @@ sub configure
         'UploadToCPAN',
 
         # After Release
+        [ 'CopyFilesFromRelease' => { filename => [ qw(README.md LICENSE CONTRIBUTING) ] } ],
         [ 'Git::Commit'         => { allow_dirty => [ qw(Changes README.md LICENSE CONTRIBUTING) ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v%t', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? (
@@ -231,7 +230,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Karen Etheridge metacpan Stopwords ModuleBuildTiny customizations KENTNL
 irc
@@ -242,7 +241,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
@@ -279,6 +278,7 @@ following F<dist.ini> (following the preamble):
 
     ;;; Gather Files
     [Git::GatherDir]
+    exclude_filename = README.md
     exclude_filename = LICENSE
     exclude_filename = CONTRIBUTING
 
@@ -386,7 +386,7 @@ following F<dist.ini> (following the preamble):
     [ReadmeAnyFromPod]
     type = markdown
     filename = README.md
-    location = root
+    location = build
 
     <specified installer(s)>
     [InstallGuide]
@@ -394,9 +394,6 @@ following F<dist.ini> (following the preamble):
 
     ;;; After Build
     [CheckSelfDependency]
-    [CopyFilesFromBuild]
-    copy = LICENSE
-    copy = CONTRIBUTING
 
     [Run::AfterBuild]
     run => if [ `dirname %d` != .build ]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi
@@ -404,9 +401,7 @@ following F<dist.ini> (following the preamble):
 
     ;;; Before Release
     [Git::Check]
-    allow_dirty = README.md
-    allow_dirty = LICENSE
-    allow_dirty = CONTRIBUTING
+    allow_dirty =
 
     [Git::CheckFor::MergeConflicts]
 
@@ -428,6 +423,11 @@ following F<dist.ini> (following the preamble):
 
 
     ;;; AfterRelease
+    [CopyFilesFromRelease]
+    copy = README.md
+    copy = LICENSE
+    copy = CONTRIBUTING
+
     [Git::Commit]
     allow_dirty = Changes
     allow_dirty = README.md
